==> jc-1.4.0.tar.gz: java/awt/Event.h <==
// public class java.awt.Event

// class file dependencies
// @dep_class ecf73b509a796b13 java_awt_Event
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Event_H_
#define _JC_java_awt_Event_H_

// Forward structure declarations
struct _jc_java_awt_Event$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_Event$sub_refs	_jc_java_awt_Event$sub_refs;
typedef struct _jc_java_awt_Event$sub_nonrefs	_jc_java_awt_Event$sub_nonrefs;
typedef struct _jc_java_awt_Event$refs	_jc_java_awt_Event$refs;
typedef struct _jc_java_awt_Event$nonrefs	_jc_java_awt_Event$nonrefs;
typedef struct _jc_java_awt_Event$object	_jc_java_awt_Event$object;

typedef struct _jc_java_awt_Event$fields_struct	_jc_java_awt_Event$fields_struct;
typedef const struct _jc_java_awt_Event$vmethods	_jc_java_awt_Event$vmethods;
typedef const struct _jc_java_awt_Event$vtable	_jc_java_awt_Event$vtable;
typedef const struct _jc_java_awt_Event$vtype	_jc_java_awt_Event$vtype;

// Class fields structure
struct _jc_java_awt_Event$fields_struct {
	jlong	serialVersionUID;
	jint	ACTION__5fEVENT;
	jint	ALT__5fMASK;
	jint	BACK__5fSPACE;
	jint	CAPS__5fLOCK;
	jint	CTRL__5fMASK;
	jint	DELETE;
	jint	DOWN;
	jint	END;
	jint	ENTER;
	jint	ESCAPE;
	jint	F1;
	jint	F10;
	jint	F11;
	jint	F12;
	jint	F2;
	jint	F3;
	jint	F4;
	jint	F5;
	jint	F6;
	jint	F7;
	jint	F8;
	jint	F9;
	jint	GOT__5fFOCUS;
	jint	HOME;
	jint	INSERT;
	jint	KEY__5fACTION;
	jint	KEY__5fACTION__5fRELEASE;
	jint	KEY__5fPRESS;
	jint	KEY__5fRELEASE;
	jint	LEFT;
	jint	LIST__5fDESELECT;
	jint	LIST__5fSELECT;
	jint	LOAD__5fFILE;
	jint	LOST__5fFOCUS;
	jint	META__5fMASK;
	jint	MOUSE__5fDOWN;
	jint	MOUSE__5fDRAG;
	jint	MOUSE__5fENTER;
	jint	MOUSE__5fEXIT;
	jint	MOUSE__5fMOVE;
	jint	MOUSE__5fUP;
	jint	NUM__5fLOCK;
	jint	PAUSE;
	jint	PGDN;
	jint	PGUP;
	jint	PRINT__5fSCREEN;
	jint	RIGHT;
	jint	SAVE__5fFILE;
	jint	SCROLL__5fABSOLUTE;
	jint	SCROLL__5fBEGIN;
	jint	SCROLL__5fEND;
	jint	SCROLL__5fLINE__5fDOWN;
	jint	SCROLL__5fLINE__5fUP;
	jint	SCROLL__5fLOCK;
	jint	SCROLL__5fPAGE__5fDOWN;
	jint	SCROLL__5fPAGE__5fUP;
	jint	SHIFT__5fMASK;
	jint	TAB;
	jint	UP;
	jint	WINDOW__5fDEICONIFY;
	jint	WINDOW__5fDESTROY;
	jint	WINDOW__5fEXPOSE;
	jint	WINDOW__5fICONIFY;
	jint	WINDOW__5fMOVED;
};
extern _jc_java_awt_Event$fields_struct _jc_java_awt_Event$class_fields;

// Constructors
extern void _jc_java_awt_Event$method$_init$36359ad9fec57683(_jc_env *, struct _jc_java_awt_Event$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_Object$object *);
extern void _jc_java_awt_Event$method$_init$4a17bf6d793d0cdd(_jc_env *, struct _jc_java_awt_Event$object *, struct _jc_java_lang_Object$object *, jlong, jint, jint, jint, jint, jint);
extern void _jc_java_awt_Event$method$_init$e536b1406311e006(_jc_env *, struct _jc_java_awt_Event$object *, struct _jc_java_lang_Object$object *, jlong, jint, jint, jint, jint, jint, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_java_awt_Event$method$controlDown$29ec4e2a91be5a89(_jc_env *, struct _jc_java_awt_Event$object *);
extern jboolean _jc_java_awt_Event$method$metaDown$309cb14c9978c907(_jc_env *, struct _jc_java_awt_Event$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_Event$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_Event$object *);
extern jboolean _jc_java_awt_Event$method$shiftDown$1ea9eebc812ef42c(_jc_env *, struct _jc_java_awt_Event$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_Event$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_Event$object *);
extern void _jc_java_awt_Event$method$translate$dbfa2518e2a9538a(_jc_env *, struct _jc_java_awt_Event$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Event$method_info$controlDown$29ec4e2a91be5a89;
extern _jc_method _jc_java_awt_Event$method_info$metaDown$309cb14c9978c907;
extern _jc_method _jc_java_awt_Event$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_Event$method_info$shiftDown$1ea9eebc812ef42c;
extern _jc_method _jc_java_awt_Event$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_awt_Event$method_info$translate$dbfa2518e2a9538a;

// Virtual methods structure
struct _jc_java_awt_Event$vmethods {
	jboolean	(*controlDown$29ec4e2a91be5a89)(_jc_env *, struct _jc_java_awt_Event$object *);
	jboolean	(*metaDown$309cb14c9978c907)(_jc_env *, struct _jc_java_awt_Event$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_Event$object *);
	jboolean	(*shiftDown$1ea9eebc812ef42c)(_jc_env *, struct _jc_java_awt_Event$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_Event$object *);
	void	(*translate$dbfa2518e2a9538a)(_jc_env *, struct _jc_java_awt_Event$object *, jint, jint);
};

// Vtable
struct _jc_java_awt_Event$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Event$vmethods	java_awt_Event;
};

// Vtype
struct _jc_java_awt_Event$vtype {
	_jc_type			type;
	_jc_java_awt_Event$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Event$sub_refs {
	struct _jc_java_lang_Object$object	*arg;
	struct _jc_java_awt_Event$object	*evt;
	struct _jc_java_lang_Object$object	*target;
};

// Reference instance fields (object)
struct _jc_java_awt_Event$refs {
    _jc_java_awt_Event$sub_refs	java_awt_Event;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Event$sub_nonrefs {
	jint	clickCount;
	jboolean	consumed;
	jint	id;
	jint	key;
	jint	modifiers;
	jlong	when;
	jint	x;
	jint	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Event$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Event$sub_nonrefs	java_awt_Event;
};

// Object instance structure
struct _jc_java_awt_Event$object {
	_jc_java_awt_Event$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Event$vtype	*vtype;
	_jc_java_awt_Event$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Event$vtype _jc_java_awt_Event$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Event, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Event$class_object;

#endif	/* _JC_java_awt_Event_H_ */

==> jc-1.4.6.tar.gz: java/awt/Event.h <==
// public class java.awt.Event

// class file dependencies
// @dep_class ecf73b509a796b13 java_awt_Event
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Event_H_
#define _JC_java_awt_Event_H_

// Forward structure declarations
struct _jc_java_awt_Event$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_Event$sub_refs	_jc_java_awt_Event$sub_refs;
typedef struct _jc_java_awt_Event$sub_nonrefs	_jc_java_awt_Event$sub_nonrefs;
typedef struct _jc_java_awt_Event$refs	_jc_java_awt_Event$refs;
typedef struct _jc_java_awt_Event$nonrefs	_jc_java_awt_Event$nonrefs;
typedef struct _jc_java_awt_Event$object	_jc_java_awt_Event$object;

typedef struct _jc_java_awt_Event$fields_struct	_jc_java_awt_Event$fields_struct;
typedef const struct _jc_java_awt_Event$vmethods	_jc_java_awt_Event$vmethods;
typedef const struct _jc_java_awt_Event$vtable	_jc_java_awt_Event$vtable;
typedef const struct _jc_java_awt_Event$vtype	_jc_java_awt_Event$vtype;

// Class fields structure
struct _jc_java_awt_Event$fields_struct {
	jlong	serialVersionUID;
	jint	ACTION__5fEVENT;
	jint	ALT__5fMASK;
	jint	BACK__5fSPACE;
	jint	CAPS__5fLOCK;
	jint	CTRL__5fMASK;
	jint	DELETE;
	jint	DOWN;
	jint	END;
	jint	ENTER;
	jint	ESCAPE;
	jint	F1;
	jint	F10;
	jint	F11;
	jint	F12;
	jint	F2;
	jint	F3;
	jint	F4;
	jint	F5;
	jint	F6;
	jint	F7;
	jint	F8;
	jint	F9;
	jint	GOT__5fFOCUS;
	jint	HOME;
	jint	INSERT;
	jint	KEY__5fACTION;
	jint	KEY__5fACTION__5fRELEASE;
	jint	KEY__5fPRESS;
	jint	KEY__5fRELEASE;
	jint	LEFT;
	jint	LIST__5fDESELECT;
	jint	LIST__5fSELECT;
	jint	LOAD__5fFILE;
	jint	LOST__5fFOCUS;
	jint	META__5fMASK;
	jint	MOUSE__5fDOWN;
	jint	MOUSE__5fDRAG;
	jint	MOUSE__5fENTER;
	jint	MOUSE__5fEXIT;
	jint	MOUSE__5fMOVE;
	jint	MOUSE__5fUP;
	jint	NUM__5fLOCK;
	jint	PAUSE;
	jint	PGDN;
	jint	PGUP;
	jint	PRINT__5fSCREEN;
	jint	RIGHT;
	jint	SAVE__5fFILE;
	jint	SCROLL__5fABSOLUTE;
	jint	SCROLL__5fBEGIN;
	jint	SCROLL__5fEND;
	jint	SCROLL__5fLINE__5fDOWN;
	jint	SCROLL__5fLINE__5fUP;
	jint	SCROLL__5fLOCK;
	jint	SCROLL__5fPAGE__5fDOWN;
	jint	SCROLL__5fPAGE__5fUP;
	jint	SHIFT__5fMASK;
	jint	TAB;
	jint	UP;
	jint	WINDOW__5fDEICONIFY;
	jint	WINDOW__5fDESTROY;
	jint	WINDOW__5fEXPOSE;
	jint	WINDOW__5fICONIFY;
	jint	WINDOW__5fMOVED;
};
extern _jc_java_awt_Event$fields_struct _jc_java_awt_Event$class_fields;

// Constructors
extern void _jc_java_awt_Event$method$_init$36359ad9fec57683(_jc_env *, struct _jc_java_awt_Event$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Event$method$_init$4a17bf6d793d0cdd(_jc_env *, struct _jc_java_awt_Event$object *, struct _jc_java_lang_Object$object *, jlong, jint, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_Event$method$_init$e536b1406311e006(_jc_env *, struct _jc_java_awt_Event$object *, struct _jc_java_lang_Object$object *, jlong, jint, jint, jint, jint, jint, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_Event$method$controlDown$29ec4e2a91be5a89(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_Event$method$metaDown$309cb14c9978c907(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_Event$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_Event$method$shiftDown$1ea9eebc812ef42c(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_Event$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Event$method$translate$dbfa2518e2a9538a(_jc_env *, struct _jc_java_awt_Event$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Event$method_info$controlDown$29ec4e2a91be5a89;
extern _jc_method _jc_java_awt_Event$method_info$metaDown$309cb14c9978c907;
extern _jc_method _jc_java_awt_Event$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_Event$method_info$shiftDown$1ea9eebc812ef42c;
extern _jc_method _jc_java_awt_Event$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_awt_Event$method_info$translate$dbfa2518e2a9538a;

// Virtual methods structure
struct _jc_java_awt_Event$vmethods {
	jboolean	(*controlDown$29ec4e2a91be5a89)(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
	jboolean	(*metaDown$309cb14c9978c907)(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
	jboolean	(*shiftDown$1ea9eebc812ef42c)(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
	void	(*translate$dbfa2518e2a9538a)(_jc_env *, struct _jc_java_awt_Event$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Event$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Event$vmethods	java_awt_Event;
};

// Vtype
struct _jc_java_awt_Event$vtype {
	_jc_type			type;
	_jc_java_awt_Event$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Event$sub_refs {
	struct _jc_java_lang_Object$object	*arg;
	struct _jc_java_awt_Event$object	*evt;
	struct _jc_java_lang_Object$object	*target;
};

// Reference instance fields (object)
struct _jc_java_awt_Event$refs {
    _jc_java_awt_Event$sub_refs	java_awt_Event;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Event$sub_nonrefs {
	jint	clickCount;
	jboolean	consumed;
	jint	id;
	jint	key;
	jint	modifiers;
	jlong	when;
	jint	x;
	jint	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Event$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Event$sub_nonrefs	java_awt_Event;
};

// Object instance structure
struct _jc_java_awt_Event$object {
	_jc_java_awt_Event$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Event$vtype	*vtype;
	_jc_java_awt_Event$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Event$vtype _jc_java_awt_Event$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Event, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Event$class_object;

#endif	/* _JC_java_awt_Event_H_ */
